Observation Classes
===================

.. currentmodule:: pynrc

.. autosummary::
   :toctree: _autosummary
   :template: custom-class-template.rst
   :recursive:
   
   NIRCam
   nrc_hci
   obs_hci
